duration property
Duration?
get
duration
The decoded length, or null when the backend cannot determine it (some streamed formats).
Implementation
Duration? get duration;
The decoded length, or null when the backend cannot determine it (some streamed formats).
Duration? get duration;