backendName property
String
get
backendName
Identifier of the concrete backend, suitable for logging (for
example "soloud").
Implementation
String get backendName;
Identifier of the concrete backend, suitable for logging (for
example "soloud").
String get backendName;