onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
@mustCallSuper
void onMount() {
_engine = AudioEngine.findAncestor(node);
}
Called when the owning node enters a live scene graph.
@override
@mustCallSuper
void onMount() {
_engine = AudioEngine.findAncestor(node);
}