onUnmount method
Called when the owning node leaves a live scene graph.
Implementation
@override
@mustCallSuper
void onUnmount() {
_engine = null;
_velocity.reset();
}
Called when the owning node leaves a live scene graph.
@override
@mustCallSuper
void onUnmount() {
_engine = null;
_velocity.reset();
}