update method
Called once per frame while the component is mounted, enabled, and
loaded. deltaSeconds is the elapsed time since the previous tick.
Implementation
@override
void update(double deltaSeconds) {
if (!positional || _engine == null) return;
final position = node.globalTransform.getTranslation();
onTransformSync(position, _velocity.derive(node, position, deltaSeconds));
}