update3d abstract method
Pushes this frame's 3D state. Called every frame for positional voices while the owning source is mounted.
Implementation
void update3d(
Vector3 position,
Vector3 velocity,
AudioAttenuation attenuation,
);
Pushes this frame's 3D state. Called every frame for positional voices while the owning source is mounted.
void update3d(
Vector3 position,
Vector3 velocity,
AudioAttenuation attenuation,
);