onUnmount method
Called when the owning node leaves a live scene graph.
Implementation
@override
void onUnmount() {
_voice?.stop();
_voice = null;
_pendingPlay = false;
super.onUnmount();
}
Called when the owning node leaves a live scene graph.
@override
void onUnmount() {
_voice?.stop();
_voice = null;
_pendingPlay = false;
super.onUnmount();
}