AnimationSpec class

A named animation: a set of channels driving target nodes.

Constructors

AnimationSpec(LocalId id, {String name = '', List<AnimationChannelSpec>? channels})
Creates an animation with the given stable id.

Properties

channels List<AnimationChannelSpec>
The channels this animation drives.
final
hashCode int
The hash code for this object.
no setterinherited
id LocalId
This animation's stable id.
final
name String
The animation's name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited