ColorValue class

A linear RGBA color.

Inheritance

Constructors

ColorValue(double r, double g, double b, double a)
const

Properties

a double
final
b double
final
g double
final
hashCode int
The hash code for this object.
no setterinherited
r double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited