realize abstract method

Component? realize(
  1. ComponentSpec spec,
  2. RealizeContext context
)

Builds a live component from spec, or returns null when it cannot be realized in the given context (for example a mesh with no resource realizer).

Implementation

Component? realize(ComponentSpec spec, RealizeContext context);