type property
String
get
type
The serialized component type name this codec handles (for example
directionalLight).
Implementation
String get type;
The serialized component type name this codec handles (for example
directionalLight).
String get type;