read property
Reads the property from a live component, or null for a property that only flows through DeclarativeComponentCodec.create (constructor-only configuration) or is provided by code.
Implementation
final PropertyValue? Function(C component, SerializeContext context)? read;