write property
Applies the property to a live component after create, or null for
constructor-only configuration.
Implementation
final void Function(C component, PropertyValue value, RealizeContext context)?
write;
Applies the property to a live component after create, or null for
constructor-only configuration.
final void Function(C component, PropertyValue value, RealizeContext context)?
write;