defaultValue property
The value used when the property is absent from a spec, or null for a required property with no default (a mesh's geometry reference).
Implementation
final PropertyValue? defaultValue;
The value used when the property is absent from a spec, or null for a required property with no default (a mesh's geometry reference).
final PropertyValue? defaultValue;