read property
Reads this property's value from a live component, used by the derived
ComponentCodec.serialize. Null for codecs that serialize by hand.
Implementation
final PropertyValue Function(Component component)? read;
Reads this property's value from a live component, used by the derived
ComponentCodec.serialize. Null for codecs that serialize by hand.
final PropertyValue Function(Component component)? read;