codecFor method
The codec for type, or null when none is registered.
Implementation
ComponentCodec? codecFor(String type) => _byType[type];
The codec for type, or null when none is registered.
ComponentCodec? codecFor(String type) => _byType[type];