realize method

Component? realize(
  1. ComponentSpec spec,
  2. RealizeContext context
)

Realizes spec into a live component, or returns null when no codec is registered for its type.

Implementation

Component? realize(ComponentSpec spec, RealizeContext context) =>
    _byType[spec.type]?.realize(spec, context);