FsceneUnsupportedFeatureException class

Thrown when a document requires a format feature this build does not support.

Implemented types

Constructors

FsceneUnsupportedFeatureException(String feature)
Creates an exception naming the unsupported feature.
const

Properties

feature String
The required feature this build does not support.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited