legacyWinding property
Whether this geometry was migrated from an older document version (< 5) that stored indices with clockwise winding.
Implementation
final bool legacyWinding;
Whether this geometry was migrated from an older document version (< 5) that stored indices with clockwise winding.
final bool legacyWinding;