GizmoColor class

A color parameter, a literal linear RGBA or a binding to a color/vec3 property. A null GizmoPrimitive.color means the editor theme's gizmo color (accent when selected).

Constructors

GizmoColor(double r, double g, double b, [double a = 1])
A literal linear RGBA color.
const
GizmoColor.bind(String bind)
Binds to the color or vec3 property at dotted path bind.
const

Properties

a double
final
b double
final
bind String?
The bound property path, or null for a literal.
final
g double
final
hashCode int
The hash code for this object.
no setterinherited
r double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) GizmoColor?