GizmoCondition class

Draws a primitive only when the property at path equals equals, for union-kind properties (a collider's shape variant).

Constructors

GizmoCondition(String path, String equals)
const

Properties

equals String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) GizmoCondition?