xray property
Whether the primitive stays visible when occluded, once depth-aware drawing exists. The v1 painter draws everything on top.
Implementation
final bool xray;
Whether the primitive stays visible when occluded, once depth-aware drawing exists. The v1 painter draws everything on top.
final bool xray;