IcosphereGeometrySpec class

A geodesic sphere made by subdividing an icosahedron.

Inheritance

Constructors

IcosphereGeometrySpec({double radius = 0.5, int subdivisions = 2})
Creates an icosphere spec.

Properties

hashCode int
The hash code for this object.
no setterinherited
radius double
Sphere radius.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subdivisions int
Recursive triangle subdivision count.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited