LayerMask32 class final
A 32-bit bitmask (collision layers/masks, render layers). Inspector, a bitmask editor.
- Inheritance
-
- Object
- PropertyConstraint<
int> - LayerMask32
Constructors
- LayerMask32()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
The tagged JSON form, a single-key map (
{'range': {...}}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited