MatrixTransform class
A transform stored as an explicit 4x4 matrix.
- Inheritance
-
- Object
- TransformSpec
- MatrixTransform
Constructors
- MatrixTransform(Matrix4 matrix)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- matrix → Matrix4
-
The 4x4 local transform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMatrix4(
) → Matrix4 -
The transform as a 4x4 matrix.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited