components property
The component set or a component's properties changed, or a resource the components reference (directly or through other resources) changed, so the components must re-realize.
Implementation
final bool components;
The component set or a component's properties changed, or a resource the components reference (directly or through other resources) changed, so the components must re-realize.
final bool components;