PhysicalSkySpec class
The built-in physically based daylight sky.
- Inheritance
-
- Object
- SkySourceSpec
- PhysicalSkySpec
Constructors
- PhysicalSkySpec({Vector3? sunDirection, double sunAngularRadius = 0.0175, double rayleighCoefficient = 2.0, Vector3? rayleighColor, double mieCoefficient = 0.005, double mieEccentricity = 0.8, Vector3? mieColor, double turbidity = 10.0, Vector3? groundColor, double energy = 1.0})
- Creates the spec with the runtime defaults.
Properties
- energy ↔ double
-
Overall output multiplier.
getter/setter pair
- groundColor ↔ Vector3
-
The color below the horizon.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mieCoefficient ↔ double
-
Strength of aerosol (Mie) scattering.
getter/setter pair
- mieColor ↔ Vector3
-
Wavelength tint of the Mie term.
getter/setter pair
- mieEccentricity ↔ double
-
Forward-scattering eccentricity of the Mie term.
getter/setter pair
- rayleighCoefficient ↔ double
-
Strength of molecular (Rayleigh) scattering.
getter/setter pair
- rayleighColor ↔ Vector3
-
Wavelength tint of the Rayleigh term.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sunAngularRadius ↔ double
-
Angular radius of the sun disk, in radians.
getter/setter pair
- sunDirection ↔ Vector3
-
Direction toward the sun.
getter/setter pair
- turbidity ↔ double
-
Aerosol density.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited