realize method

  1. @override
Component realize(
  1. ComponentSpec spec,
  2. RealizeContext context
)
override

Builds a live component from spec, or returns null when it cannot be realized in the given context (for example a mesh with no resource realizer).

Implementation

@override
Component realize(ComponentSpec spec, RealizeContext context) =>
    ForeignComponent(
      ComponentSpec(spec.type, properties: {...spec.properties}),
    );