load property
Whether the instance's content loads eagerly or streams in. Asset-backed loaders resolve source relative to the declaring document for both policies.
Implementation
final LoadPolicy load;
Whether the instance's content loads eagerly or streams in. Asset-backed loaders resolve source relative to the declaring document for both policies.
final LoadPolicy load;