environment method

EnvironmentSettings? environment(
  1. LocalId id
)

The realized look for an EnvironmentResource id, or null when id is not an environment resource. Environments are GPU-bound and async, so they are built in preload; this returns the cached result.

Implementation

EnvironmentSettings? environment(LocalId id) => _environments[id];