views property
Serialized render views, in order. Each binds a camera node to a target (a RenderTextureResource id, or null for the screen).
Implementation
final List<RenderViewSpec> views = [];
Serialized render views, in order. Each binds a camera node to a target (a RenderTextureResource id, or null for the screen).
final List<RenderViewSpec> views = [];