sunLight property
The sky-driven analytic sun, or null for image-based sky lighting only. Applies only when source is a sky with a sun.
Implementation
SunLightSpec? sunLight;
The sky-driven analytic sun, or null for image-based sky lighting only. Applies only when source is a sky with a sun.
SunLightSpec? sunLight;