SkyboxSpec class
The stage skybox: the visible background drawn behind all geometry.
Constructors
- SkyboxSpec(SkySourceSpec source, {double intensity = 1.0})
- Creates the spec.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- intensity ↔ double
-
Scales the sampled radiance for an environment sky source.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ SkySourceSpec
-
What the sky looks like.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited