SortedDescending class final

A list of objects must stay sorted by strictly descending fieldName (LOD levels by screen size).

Inheritance

Constructors

SortedDescending(String fieldName)
const

Properties

fieldName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
The tagged JSON form, a single-key map ({'range': {...}}).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited