SphereGeometrySpec class

A UV sphere.

Inheritance

Constructors

SphereGeometrySpec({double radius = 0.5, int segments = 32, int rings = 16})
Creates a sphere spec.

Properties

hashCode int
The hash code for this object.
no setterinherited
radius double
The sphere radius.
final
rings int
Divisions from pole to pole.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments int
Divisions around the equator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited