environmentRef property

LocalId? environmentRef
getter/setter pair

The global environment resource the stage's look comes from (the image-based-lighting environment, intensity, exposure, tone mapping, reflection size, skybox, and sky lighting). The realizer defaults to a studio look when this is null or does not resolve.

Implementation

LocalId? environmentRef;