skyEnvironment property
Sky-driven lighting (a sky baked into the environment on a refresh policy), when set. While set, it owns the scene environment, so environment is not applied.
Implementation
SkyEnvironmentSpec? skyEnvironment;
Sky-driven lighting (a sky baked into the environment on a refresh policy), when set. While set, it owns the scene environment, so environment is not applied.
SkyEnvironmentSpec? skyEnvironment;