TextureResource class

A texture sourced either from an embedded payload chunk or an external image asset.

Inheritance

Constructors

TextureResource(LocalId id, {LocalId? payload, AssetRef? asset})
Creates a texture from an embedded payload or an external asset.

Properties

asset AssetRef?
The external image asset, or null when payload is set.
final
hashCode int
The hash code for this object.
no setterinherited
id LocalId
This resource's stable, document-scoped id.
finalinherited
payload LocalId?
The embedded image chunk, or null when asset is set.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited