TorusGeometrySpec class

A torus centered on the origin around the Y axis.

Inheritance

Constructors

TorusGeometrySpec({double radius = 0.5, double tubeRadius = 0.15, int radialSegments = 32, int tubularSegments = 16})
Creates a torus spec.

Properties

hashCode int
The hash code for this object.
no setterinherited
radialSegments int
Divisions around the main ring.
final
radius double
Distance from the origin to the tube center.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tubeRadius double
Tube radius.
final
tubularSegments int
Divisions around the tube.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited