TrsTransform class
A transform stored as decomposed translation, rotation, and scale.
- Inheritance
-
- Object
- TransformSpec
- TrsTransform
Constructors
- TrsTransform({Vector3? translation, Quaternion? rotation, Vector3? scale})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotation → Quaternion
-
The rotation component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → Vector3
-
The scale component.
final
- translation → Vector3
-
The translation component.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMatrix4(
) → Matrix4 -
The transform as a 4x4 matrix.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited