WidgetSlotBuilder typedef
WidgetSlotBuilder =
Widget Function()
Builds the widget subtree bound to a slot name.
Implementation
typedef WidgetSlotBuilder = Widget Function();
Builds the widget subtree bound to a slot name.
typedef WidgetSlotBuilder = Widget Function();