nodeRefOf function Assets and loading

NodeRefValue? nodeRefOf(
  1. Node? node
)

The serialized reference for node, or null when it was not realized from a document node (a hand-built node has no document id).

Implementation

NodeRefValue? nodeRefOf(Node? node) {
  if (node == null) return null;
  final id = nodeFsceneId(node);
  return id == null ? null : NodeRefValue(id);
}