Texture class base
Properties
- bytesPerTexel → int
-
no setter
- coordinateSystem ↔ TextureCoordinateSystem
-
getter/setter pair
- enableRenderTargetUsage → bool
-
no setter
- enableShaderReadUsage → bool
-
no setter
- enableShaderWriteUsage → bool
-
no setter
- format → PixelFormat
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
no setter
- isValid → bool
-
no setter
- mipLevelCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
no setter
- sliceCount → int
-
no setter
- storageMode → StorageMode
-
no setter
- textureType → TextureType
-
no setter
- width → int
-
no setter
Methods
-
asImage(
) → Image -
getBaseMipLevelSizeInBytes(
) → int -
getMipLevelSizeInBytes(
int mipLevel) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overwrite(
ByteData sourceBytes, {int mipLevel = 0, int slice = 0}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fullMipCount(
int width, int height) → int