applyLightingToTarget property
Whether to automatically apply evaluated sun colors and intensities to the light.
Implementation
bool applyLightingToTarget;
Whether to automatically apply evaluated sun colors and intensities to the light.
bool applyLightingToTarget;