vertexCount property
int
get
vertexCount
Total number of line vertices accumulated for the current frame.
Implementation
static int get vertexCount => _positions.length ~/ 3;
Total number of line vertices accumulated for the current frame.
static int get vertexCount => _positions.length ~/ 3;