onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
void onMount() {
_initialPosition = node.position.clone();
_initialRotation = node.rotation.clone();
_initialized = true;
}
Called when the owning node enters a live scene graph.
@override
void onMount() {
_initialPosition = node.position.clone();
_initialRotation = node.rotation.clone();
_initialized = true;
}