JoystickCallback typedef
JoystickCallback =
void Function(Vector2 direction)
Callback for joystick input events emitting a normalized 2D direction vector.
In screen space, dragging upward produces a negative Y component (direction.y < 0).
Implementation
typedef JoystickCallback = void Function(vm.Vector2 direction);