factory property
Factory function creating a new node instance when the idle pool is exhausted.
Implementation
final Node Function() factory;
Factory function creating a new node instance when the idle pool is exhausted.
final Node Function() factory;