PoissonDiscSampler class Gameplay kit

Poisson-disc spatial point distribution generator for natural obstacle and foliage scattering.

Constructors

PoissonDiscSampler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sampleRect(double width, double height, double minDistance, {int maxCandidates = 30, int? seed}) List<Vector2>
Generates a set of 2D points within a rectangular area with minimum separation minDistance.