onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
void onMount() {
_smoothedPivotWorld = _currentRawPivotWorld;
currentLength = targetLength;
_updateSocketTransform();
_initialized = true;
}
Called when the owning node enters a live scene graph.
@override
void onMount() {
_smoothedPivotWorld = _currentRawPivotWorld;
currentLength = targetLength;
_updateSocketTransform();
_initialized = true;
}