positionLagSpeed property
Speed at which the lagged position catches up to the target (higher = faster).
Implementation
double positionLagSpeed;
Speed at which the lagged position catches up to the target (higher = faster).
double positionLagSpeed;