socketOffset property
Vector3
socketOffset
getter/setter pair
Local offset applied at the camera socket end along socket right (X) and up (Y).
Implementation
vm.Vector3 socketOffset;
Local offset applied at the camera socket end along socket right (X) and up (Y).
vm.Vector3 socketOffset;