targetOffset property
Vector3
targetOffset
getter/setter pair
Local offset applied along world axes from the owning node's origin to the boom's pivot.
Implementation
vm.Vector3 targetOffset;
Local offset applied along world axes from the owning node's origin to the boom's pivot.
vm.Vector3 targetOffset;