registerClips method
Registers a list of audio clips for a specific surface type.
Implementation
void registerClips(SurfaceMaterialType type, List<AudioClip> clips) {
_banks[type] = List.from(clips);
}
Registers a list of audio clips for a specific surface type.
void registerClips(SurfaceMaterialType type, List<AudioClip> clips) {
_banks[type] = List.from(clips);
}