CharacterMovement class

Result of one kinematic character move-and-slide.

Constructors

CharacterMovement({required Vector3 translation, required bool grounded, required bool slidingDownSlope})

Properties

grounded bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slidingDownSlope bool
final
translation → Vector3
The corrected translation actually applied.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited