onMount method

  1. @override
void onMount()
override

Called when the owning node enters a live scene graph.

Implementation

@override
void onMount() {
  if (_register(silent: false)) {
    // A character controller that mounted first is waiting on these
    // handles.
    retryPendingPhysicsRegistrations();
  } else {
    addPendingPhysicsRegistration(this);
  }
}