CollisionEvent class sealed Physics

Collision lifecycle events for a PhysicsWorld's bodies, resolved to scene nodes and collider components.

Implementers

Properties

colliderA Component
final
colliderB Component
final
hashCode int
The hash code for this object.
no setterinherited
nodeA Node
final
nodeB Node
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited