onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
void onMount() {
if (!_register(silent: false)) addPendingPhysicsRegistration(this);
}
Called when the owning node enters a live scene graph.
@override
void onMount() {
if (!_register(silent: false)) addPendingPhysicsRegistration(this);
}