JointMotor class

Drives a joint axis toward a target position and/or velocity.

Constructors

JointMotor({double targetPosition = 0, double targetVelocity = 0, double stiffness = 0, double damping = 0, double maxForce = double.infinity, JointMotorModel model = JointMotorModel.acceleration})
const

Properties

damping double
final
hashCode int
The hash code for this object.
no setterinherited
maxForce double
final
model JointMotorModel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stiffness double
final
targetPosition double
final
targetVelocity double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited