snapToGround property
Maximum ground distance to snap down to when walking off edges, or null to disable snapping.
Implementation
final double? snapToGround;
Maximum ground distance to snap down to when walking off edges, or null to disable snapping.
final double? snapToGround;