backendName property
String
get
backendName
Identifier of the concrete backend, suitable for logging (for
example "rapier3d").
Implementation
String get backendName;
Identifier of the concrete backend, suitable for logging (for
example "rapier3d").
String get backendName;