restore method

bool restore(
  1. Uint8List snapshot
)

Restores state from a snapshot produced by this backend, returning false if the bytes could not be decoded. Throws UnsupportedError unless supportsSnapshot.

Implementation

bool restore(Uint8List snapshot) =>
    throw UnsupportedError('$backendName has no world restore');