setBodyKinematicTargetPose abstract method
Pushes the pose a kinematic body should reach by the next step.
Implementation
void setBodyKinematicTargetPose(
int bodyHandle,
Vector3 translation,
Quaternion rotation,
);
Pushes the pose a kinematic body should reach by the next step.
void setBodyKinematicTargetPose(
int bodyHandle,
Vector3 translation,
Quaternion rotation,
);