interpolationAlpha property

double get interpolationAlpha

The most recent interpolation fraction between physics steps, for components smoothing their own rendering the way dynamic bodies do.

Implementation

double get interpolationAlpha => _interpolationAlpha;