onUnmount method
Called when the owning node leaves a live scene graph.
Implementation
@override
void onUnmount() {
final handle = _handle;
if (handle != null) _sim?.destroyBody(handle);
_handle = null;
_world = null;
}
Called when the owning node leaves a live scene graph.
@override
void onUnmount() {
final handle = _handle;
if (handle != null) _sim?.destroyBody(handle);
_handle = null;
_world = null;
}