TriggerEntered class Physics

A collider entered a trigger volume.

Inheritance

Constructors

TriggerEntered({required Node nodeA, required Node nodeB, required Component colliderA, required Component colliderB})

Properties

colliderA Component
finalinherited
colliderB Component
finalinherited
hashCode int
The hash code for this object.
no setterinherited
nodeA Node
finalinherited
nodeB Node
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited