detail property
Strength of the four immediate-neighbour samples. This restores tight contact detail that the wider sampling disk and blur can soften.
Only used by AmbientOcclusionMethod.obscurance.
Implementation
double detail = 0.5;
Strength of the four immediate-neighbour samples. This restores tight contact detail that the wider sampling disk and blur can soften.
Only used by AmbientOcclusionMethod.obscurance.
double detail = 0.5;