horizonAngle property

double horizonAngle
getter/setter pair

Minimum sine of the sample angle above the surface horizon. Samples closer to tangent are rejected to prevent shallow surfaces from self-occluding because of depth precision and coarse tessellation.

Only used by AmbientOcclusionMethod.obscurance.

Implementation

double horizonAngle = 0.06;