thickness property
Assumed occluder thickness in world units when visibilityBitmask is enabled. Surfaces stop occluding the hemisphere beyond this depth behind their front face.
Implementation
double thickness = 0.5;
Assumed occluder thickness in world units when visibilityBitmask is enabled. Surfaces stop occluding the hemisphere beyond this depth behind their front face.
double thickness = 0.5;