loop property
Whether the clip should wrap around at the end of the animation (or the beginning, when playing in reverse) instead of pausing.
Implementation
bool loop = false;
Whether the clip should wrap around at the end of the animation (or the beginning, when playing in reverse) instead of pausing.
bool loop = false;