bindPose property
The node's rest-pose transform, captured when the node is first registered with an AnimationPlayer.
Implementation
DecomposedTransform bindPose;
The node's rest-pose transform, captured when the node is first registered with an AnimationPlayer.
DecomposedTransform bindPose;