onUnmount method
Called when the owning node leaves a live scene graph.
Implementation
@override
void onUnmount() {
_world?.unregisterCollider(this);
_world = null;
}
Called when the owning node leaves a live scene graph.
@override
void onUnmount() {
_world?.unregisterCollider(this);
_world = null;
}