ccdEnabled property
When true, the backend uses continuous collision detection to
prevent fast-moving bodies from tunneling through thin colliders.
Implementation
@override
bool get ccdEnabled => _ccdEnabled;
When true, the backend uses continuous collision detection to
prevent fast-moving bodies from tunneling through thin colliders.
@override
bool get ccdEnabled => _ccdEnabled;