onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
void onMount() {
final world = findAncestorWorld(node);
if (world == null) return;
_world = world;
world.registerBody(this);
}
Called when the owning node enters a live scene graph.
@override
void onMount() {
final world = findAncestorWorld(node);
if (world == null) return;
_world = world;
world.registerBody(this);
}