BoxShape class Physics
An axis-aligned box of the given halfExtents centered at the collider's local origin.
Constructors
- BoxShape({required Vector3 halfExtents})
Properties
- halfExtents → Vector3
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited