releaseInput method
void
releaseInput()
Releases any held input (call when the driving view loses focus so keys released elsewhere do not stick).
Implementation
void releaseInput() {}
Releases any held input (call when the driving view loses focus so keys released elsewhere do not stick).
void releaseInput() {}