enabled property
Whether input is forwarded. When false the child still shows but input is ignored (and held keys are released).
Implementation
final bool enabled;
Whether input is forwarded. When false the child still shows but input is ignored (and held keys are released).
final bool enabled;