passIndex property
Index of the pass that wrote this content, or -1 for textures acquired while the graph was being built.
Implementation
final int passIndex;
Index of the pass that wrote this content, or -1 for textures acquired while the graph was being built.
final int passIndex;