CollisionEvent class sealed Physics

Base type for collision lifecycle events streamed by a physics world.

Subscribe via PhysicsWorld.collisions. The same pair fires CollisionBegan / CollisionEnded for solid contacts and TriggerEntered / TriggerExited for trigger volumes.

Implementers

Properties

colliderA Component
no setter
colliderB Component
no setter
hashCode int
The hash code for this object.
no setterinherited
nodeA Node
The node owning colliderA. nodeA and nodeB may be the same when a compound body's children touch each other.
no setter
nodeB Node
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited