ColorStop class Particles

One color stop of a ColorGradient: a linear RGBA color at normalized time t.

Constructors

ColorStop(double t, Vector4 color)
Creates a stop placing color (linear RGBA) at normalized time t.
const

Properties

color → Vector4
Linear RGBA color at t.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
t double
Normalized time of this stop, in [0, 1].
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited