isAttached property
bool
get
isAttached
Whether this component is currently attached to a node.
Implementation
bool get isAttached => _node != null;
Whether this component is currently attached to a node.
bool get isAttached => _node != null;