CompoundShape class Physics
A union of children, each positioned by its own local pose.
Use this when one collider needs to represent a non-convex shape made of several primitives (for example an L-block made of two boxes).
Constructors
-
CompoundShape({required List<
CompoundChild> children})
Properties
-
children
→ List<
CompoundChild> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited