ConstantFloat class Particles

A FloatDistribution that is value for every particle.

Inheritance

Constructors

ConstantFloat(double value)
Creates a constant distribution.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The constant value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sample(double normalizedAge, double random01) double
Returns the value for a particle at normalizedAge with per-particle random random01.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited