ContactPoint class Physics

One contact point in a CollisionBegan event.

worldNormal points from collider A into collider B. impulse is the normal impulse applied to resolve the contact this step (zero for trigger events). separation is positive when bodies are separated and negative when they are interpenetrating.

Constructors

ContactPoint({required Vector3 worldPosition, required Vector3 worldNormal, required double impulse, required double separation})

Properties

hashCode int
The hash code for this object.
no setterinherited
impulse double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separation double
final
worldNormal → Vector3
final
worldPosition → Vector3
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited