ConvexHullShape class Physics
The convex hull of points, stored as packed xyz triplets.
Constructors
- ConvexHullShape({required Float32List points})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- points → Float32List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited