CurveFloat class Particles
A FloatDistribution that samples curve over the particle's normalized age and scales it by scale.
- Inheritance
-
- Object
- FloatDistribution
- CurveFloat
Constructors
- CurveFloat(ParticleCurve curve, {double scale = 1.0})
-
Creates a curve-over-life distribution.
const
Properties
- curve → ParticleCurve
-
The curve sampled over normalized age.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
Multiplier applied to the sampled curve value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sample(
double normalizedAge, double random01) → double -
Returns the value for a particle at
normalizedAgewith per-particle randomrandom01.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited