DecodedHdr class Assets and loading

A decoded HDR image: linear RGBA float pixels (alpha 1), row-major, row 0 at the top.

Constructors

DecodedHdr(Float32List pixels, int width, int height)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
pixels Float32List
width * height * 4 linear floats, RGBA, row 0 at the top.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited