fStop property

double fStop
getter/setter pair

The aperture f-number. Smaller stops (1.4, 2.8) give a shallower depth of field and larger bokeh; the aperture diameter is focalLength / fStop. Uses the same vocabulary as Scene.physicalCameraExposure so one set of camera numbers can drive exposure and blur.

Implementation

double fStop = 2.8;