shadowFilter property
The percentage-closer filtering pattern used to sample the shadow map.
Implementation
DirectionalShadowFilter shadowFilter;
The percentage-closer filtering pattern used to sample the shadow map.
DirectionalShadowFilter shadowFilter;