onMount method
Called when the owning node enters a live scene graph.
Implementation
@override
void onMount() {
node.internalRenderScene?.addDirectionalLight(this);
}
Called when the owning node enters a live scene graph.
@override
void onMount() {
node.internalRenderScene?.addDirectionalLight(this);
}