sample abstract method
Writes the spawn position and unit emission direction for particle
index into storage.
Implementation
void sample(ParticleStorage storage, int index);
Writes the spawn position and unit emission direction for particle
index into storage.
void sample(ParticleStorage storage, int index);