EnvironmentMap.empty constructor

EnvironmentMap.empty()

A black environment that contributes no image-based lighting.

Specular reflections are black and the diffuse term is zero, so objects are lit only by analytic lights (if any).

Implementation

factory EnvironmentMap.empty() {
  return EnvironmentMap._(
    Material.getBlackPlaceholderTexture(),
    _zeroSphericalHarmonics(),
  );
}