prefilteredRadianceTexture property

Texture get prefilteredRadianceTexture

The 2D prefiltered radiance for the equirect layouts, or a dummy when the radiance is a cube (the material's samplerCube is used instead). Both the 2D and cube samplers are always bound; the layout flag selects one.

Implementation

gpu.Texture get prefilteredRadianceTexture => usesCubeRadianceLayout
    ? Material.getBlackPlaceholderTexture()
    : _prefilteredRadianceTexture;