EnvironmentVolumeBounds class sealed Lighting and environment
The shape of an EnvironmentVolume's region.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
distanceTo(
Vector3 point) → double -
Distance from
pointto the boundary surface in world units,0whenpointis inside. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited