distanceTo abstract method
Distance from point to the boundary surface in world units, 0 when
point is inside.
Implementation
double distanceTo(Vector3 point);
Distance from point to the boundary surface in world units, 0 when
point is inside.
double distanceTo(Vector3 point);