blendDistance property
Local-space fade band outside the region over which the contribution falls
from full to zero. 0 is a hard edge.
Implementation
double blendDistance;
Local-space fade band outside the region over which the contribution falls
from full to zero. 0 is a hard edge.
double blendDistance;