EquirectImageFormat enum Assets and loading

The container of an equirectangular image, detected from its bytes.

Inheritance
Available extensions

Values

radianceHdr → const EquirectImageFormat

Radiance .hdr (RGBE), decoded to linear float.

openExr → const EquirectImageFormat

OpenEXR .exr, decoded to linear float.

ldr → const EquirectImageFormat

A standard sRGB image (PNG, JPEG, and so on), decoded by the platform image codec and interpreted as sRGB.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EquirectImageFormat>
A constant List of the values in this enum, in order of their declaration.