ExrFormatException class Assets and loading

Thrown when decodeOpenExr cannot parse the bytes as an OpenEXR image.

Implemented types

Constructors

ExrFormatException(String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited