requestCapture method

void requestCapture()

Captures on the next draw that samples this source. The trigger for ExternalTextureUpdate.manual; under the other policies it skips ahead of the schedule.

Implementation

void requestCapture() => _captureRequested = true;