ExternalTextureUpdate.interval constructor

const ExternalTextureUpdate.interval(
  1. Duration duration
)

Capture at most once per duration. Use for a video on a distant billboard, or any source that does not need to be current.

Implementation

const factory ExternalTextureUpdate.interval(Duration duration) =
    _IntervalUpdate;