color property

Vector3 color
getter/setter pair

Fog color, linear (not sRGB). Distant opaque geometry converges to this, so matching it to the horizon color makes geometry dissolve into the sky.

Implementation

Vector3 color = Vector3(0.6, 0.7, 0.8);