cutoffDistance property
Distance past which fog is not applied (0 disables the cutoff). Useful to exclude a far layer that already reads as hazed.
Implementation
double cutoffDistance = 0.0;
Distance past which fog is not applied (0 disables the cutoff). Useful to exclude a far layer that already reads as hazed.
double cutoffDistance = 0.0;