heightFalloff property
How fast fog thins with altitude above height (0 = uniform, no height fog). Only affects FogMode.exponential. Larger hugs the ground more tightly.
Implementation
double heightFalloff = 0.0;
How fast fog thins with altitude above height (0 = uniform, no height fog). Only affects FogMode.exponential. Larger hugs the ground more tightly.
double heightFalloff = 0.0;