color method
Sets the color applied to vertices added after this call.
Implementation
GeometryBuilder color(Vector4 value) {
_color = value.clone();
return this;
}
Sets the color applied to vertices added after this call.
GeometryBuilder color(Vector4 value) {
_color = value.clone();
return this;
}