tangent method
Sets the tangent applied to vertices added after this call.
Implementation
GeometryBuilder tangent(Vector4 value) {
_tangent = value.clone();
return this;
}
Sets the tangent applied to vertices added after this call.
GeometryBuilder tangent(Vector4 value) {
_tangent = value.clone();
return this;
}