texCoord method
Sets the texture coordinate applied to vertices added after this call.
Implementation
GeometryBuilder texCoord(Vector2 value) {
_texCoord = value.clone();
return this;
}
Sets the texture coordinate applied to vertices added after this call.
GeometryBuilder texCoord(Vector2 value) {
_texCoord = value.clone();
return this;
}