GradientColor class Particles

A ColorDistribution that samples gradient over the particle's normalized age (color over life).

Inheritance

Constructors

GradientColor(ColorGradient gradient)
Creates a color-over-life distribution.
const

Properties

gradient ColorGradient
The gradient sampled over normalized age.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sample(double normalizedAge, double random01, [Vector4? out]) → Vector4
Writes the color for a particle at normalizedAge with per-particle random random01 into out (allocated when null) and returns it.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited