HeightFieldShape class Physics

A row-major heightfield of width x depth samples, scaled by scale. Heights are sampled in the local XZ plane and offset along Y.

Inheritance

Constructors

HeightFieldShape({required int width, required int depth, required Float32List heights, required Vector3 scale})

Properties

depth int
final
hashCode int
The hash code for this object.
no setterinherited
heights Float32List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale → Vector3
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited