InstancedMesh constructor
Creates an instanced mesh that draws geometry shaded by
material. It starts with no instances; add them with
addInstance.
Implementation
InstancedMesh({required this.geometry, required this.material});
Creates an instanced mesh that draws geometry shaded by
material. It starts with no instances; add them with
addInstance.
InstancedMesh({required this.geometry, required this.material});