consumeInvalidation method
Whether this volume asked to be refilled from scratch, clearing the request.
Implementation
bool consumeInvalidation() {
final pending = _invalidated;
_invalidated = false;
return pending;
}
Whether this volume asked to be refilled from scratch, clearing the request.
bool consumeInvalidation() {
final pending = _invalidated;
_invalidated = false;
return pending;
}