ghostCount property
Number of internal-reflection ghosts along the line through the screen center. Values above 8 are clamped to 8 when rendered.
Implementation
int ghostCount = 4;
Number of internal-reflection ghosts along the line through the screen center. Values above 8 are clamped to 8 when rendered.
int ghostCount = 4;