ghostSpacing property
Spacing between successive ghosts, as a fraction of the distance from the source's mirrored position to the screen center.
Implementation
double ghostSpacing = 0.3;
Spacing between successive ghosts, as a fraction of the distance from the source's mirrored position to the screen center.
double ghostSpacing = 0.3;