cascades property
The shadow cascades matching shadowMap, near-to-far, or empty when there is no shadow map this frame.
Implementation
final List<ShadowCascade> cascades;
The shadow cascades matching shadowMap, near-to-far, or empty when there is no shadow map this frame.
final List<ShadowCascade> cascades;