orthographic property
Whether the camera projection is orthographic (parallel view rays), so view-space x and y do not scale with depth.
Implementation
final bool orthographic;
Whether the camera projection is orthographic (parallel view rays), so view-space x and y do not scale with depth.
final bool orthographic;