ssaoMultiBounce property
How much occluded indirect diffuse converges toward the surface albedo instead of black (the multi-bounce approximation).
Implementation
final double ssaoMultiBounce;
How much occluded indirect diffuse converges toward the surface albedo instead of black (the multi-bounce approximation).
final double ssaoMultiBounce;