name property
The name of this material, used for identification.
The importers set it from the source asset's material name; empty when the source material is unnamed or the material was created directly.
Implementation
String name = '';
The name of this material, used for identification.
The importers set it from the source asset's material name; empty when the source material is unnamed or the material was created directly.
String name = '';