bindUniformBlock method

void bindUniformBlock(
  1. RenderPass pass,
  2. Shader shader,
  3. TransientWriter transientsBuffer
)

Binds only the MaterialParams uniform block on shader into pass, not the sampler parameters. Used to make the block available to the vertex stage, whose generated shader declares the block but not the material's samplers.

Implementation

void bindUniformBlock(
  gpu.RenderPass pass,
  gpu.Shader shader,
  TransientWriter transientsBuffer,
) {
  if (_block.lengthInBytes > 0) {
    pass.bindUniform(
      shader.getUniformSlot(_blockName),
      transientsBuffer.emplace(_block),
    );
  }
}