selected property
String?
get
selected
The currently selected variant name, or null when the defaults are active.
Implementation
String? get selected => _selected;
The currently selected variant name, or null when the defaults are active.
String? get selected => _selected;