MemoryCategory class Assets and loading

One category of resident GPU memory.

Annotations

Constructors

MemoryCategory({required String name, required int? bytes, required int count})
const

Properties

bytes int?
Resident bytes, or null where the size is not knowable from Dart.
final
count int
How many resources the category holds.
final
hashCode int
The hash code for this object.
no setterinherited
name String
What this category holds (textures, scene templates).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited