normals property
Vertex normals (three floats each), or null to let the upload generate or default them.
Implementation
final Float32List? normals;
Vertex normals (three floats each), or null to let the upload generate or default them.
final Float32List? normals;