MeshTriangle class Geometry

One triangle of a MeshData, yielded by MeshData.triangles.

Constructors

MeshTriangle(int index, int a, int b, int c, Vector3 pa, Vector3 pb, Vector3 pc)

Properties

a int
The three vertex indices.
final
b int
The three vertex indices.
final
c int
The three vertex indices.
final
hashCode int
The hash code for this object.
no setterinherited
index int
The triangle's index in the mesh.
final
pa → Vector3
The three corner positions.
final
pb → Vector3
The three corner positions.
final
pc → Vector3
The three corner positions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited