castsShadows property
Whether this node's meshes cast shadows. Defaults to true.
This does not affect whether the meshes receive shadows. The value is not inherited by children.
Implementation
bool castsShadows = true;
Whether this node's meshes cast shadows. Defaults to true.
This does not affect whether the meshes receive shadows. The value is not inherited by children.
bool castsShadows = true;