getComponents<T> method
Returns every attached component of type T, in attach order.
Implementation
Iterable<T> getComponents<T>() => _components.whereType<T>();
Returns every attached component of type T, in attach order.
Iterable<T> getComponents<T>() => _components.whereType<T>();