skin property
The skin attached to this node, used for skeletal animation. Set by importers (both the offline .model path and the runtime glTF/GLB loader).
Implementation
Skin? skin;
The skin attached to this node, used for skeletal animation. Set by importers (both the offline .model path and the runtime glTF/GLB loader).
Skin? skin;