NodeFilter class Rendering

Selects which scene nodes an object-filtered draw includes.

Used by the object-filtered draw (the selection mask, and the public RenderPassContext.drawObjects) to pick a subset of the scene's drawable geometry to render flat into a target.

Constructors

NodeFilter.all()
Includes every visible drawable node.
const
NodeFilter.layers(int mask)
Includes nodes whose render layers intersect mask.
const
NodeFilter.where(bool predicate(Object node))
Includes nodes for which predicate returns true.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited