dollySpeed property
Proportional dolly rate; the distance changes by exp(-amount*dollySpeed)
so a step feels the same near or far.
Implementation
double dollySpeed;
Proportional dolly rate; the distance changes by exp(-amount*dollySpeed)
so a step feels the same near or far.
double dollySpeed;