OrthographicSize.cover constructor

const OrthographicSize.cover(
  1. double width,
  2. double height
)

Shows at most width by height world units, cropping one axis to match the aspect ratio so the view is filled.

Implementation

const factory OrthographicSize.cover(double width, double height) =
    OrthographicCover;