OverlapHit class Physics

One collider returned by an overlap query (sphere or box).

Constructors

OverlapHit({required Node node, required Component collider})

Properties

collider Component
final
hashCode int
The hash code for this object.
no setterinherited
node Node
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited