ParticleKeyframe class Particles

One control point of a ParticleCurve: a value at normalized time t (in [0, 1]).

Constructors

ParticleKeyframe(double t, double value)
Creates a keyframe placing value at normalized time t.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
t double
Normalized time of this keyframe, clamped into [0, 1] when baked.
final
value double
The curve value at t.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited