fovNear property

double fovNear
getter/setter pair

Distance to the near clipping plane. Geometry closer than this is clipped away.

The scene rasterizes with the largest near plane that clips nothing visible, with this as the floor (Scene.fitNearPlane), so depth precision follows the content and this only needs to be small enough that nothing the camera approaches is clipped.

Implementation

double fovNear;