PerspectiveProjection class Scene graph
A standard pinhole perspective projection.
- Inheritance
-
- Object
- CameraProjection
- PerspectiveProjection
Constructors
- PerspectiveProjection({double fovRadiansY = 45 * degrees2Radians, double near = 0.1, double far = 1000.0})
-
Creates a PerspectiveProjection with a vertical field of view
fovRadiansYand anear/farclip range.
Properties
- far ↔ double
-
Distance to the far clipping plane. Must be greater than near.
getter/setter pair
- fovRadiansY ↔ double
-
Vertical field of view, in radians. The horizontal field of view is
derived from the render target's aspect ratio at draw time.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- near ↔ double
-
Distance to the near clipping plane. Geometry closer is clipped away.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getProjectionMatrix(
double aspectRatio) → Matrix4 -
Returns the projection matrix for a render target of the given
aspectRatio(width / height).override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited