sunLightColor property
Linear-RGB color the sun contributes as a directional light. Combined with sunLightIntensity.
Implementation
@override
Vector3 get sunLightColor => Vector3(1.0, 0.98, 0.95);
Linear-RGB color the sun contributes as a directional light. Combined with sunLightIntensity.
@override
Vector3 get sunLightColor => Vector3(1.0, 0.98, 0.95);