emissiveTexture property
Optional emissive texture. Defaults to white when null and is gated by emissiveFactor.
Accepts a Texture2D or a RenderTexture (sampled live).
Implementation
TextureSource? emissiveTexture;
Optional emissive texture. Defaults to white when null and is gated by emissiveFactor.
Accepts a Texture2D or a RenderTexture (sampled live).
TextureSource? emissiveTexture;