reflectionRoughnessTexture property

  1. @override
Texture? get reflectionRoughnessTexture

The metallic-roughness texture the camera depth prepass samples so screen-space reflections have a per-pixel roughness (roughness in G), or null to use a fully-rough placeholder. The base material has none, so it reads as fully rough and receives no screen-space reflection; a lit material overrides this.

Implementation

@override
gpu.Texture? get reflectionRoughnessTexture =>
    resolveTextureSource(metallicRoughnessTexture);