maxSubsteps property
Maximum number of fixed steps consumed per frame. When the frame interval falls behind this many steps, remaining accumulated time is dropped to keep simulation from spiralling.
Implementation
int maxSubsteps = 8;
Maximum number of fixed steps consumed per frame. When the frame interval falls behind this many steps, remaining accumulated time is dropped to keep simulation from spiralling.
int maxSubsteps = 8;