PointLightComponent constructor
PointLightComponent(
- PointLight light
Creates a component that lights the scene with light.
Implementation
PointLightComponent(this.light);
Creates a component that lights the scene with light.
PointLightComponent(this.light);