PolylineCap enum
How a PolylineGeometry finishes its two end points.
Values
- butt → const PolylineCap
-
The strip ends flat at the end point.
- round → const PolylineCap
-
A half-disk rounds the end off to the line's half-width.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PolylineCap> - A constant List of the values in this enum, in order of their declaration.