setTexture method
Assigns a texture to a sampler uniform by name.
Implementation
void setTexture(
String name,
gpu.Texture? texture, {
gpu.SamplerOptions? sampler,
}) => _bindings.setTexture(name, texture, sampler: sampler);
Assigns a texture to a sampler uniform by name.
void setTexture(
String name,
gpu.Texture? texture, {
gpu.SamplerOptions? sampler,
}) => _bindings.setTexture(name, texture, sampler: sampler);