PostInsertion enum

Where in the post-processing chain a PostEffect runs.

Inheritance
Available extensions

Values

beforeTonemap → const PostInsertion

Runs on the linear HDR scene color, before tone mapping. The shader should output linear HDR premultiplied by alpha, the same contract as a material fragment shader.

afterTonemap → const PostInsertion

Runs on the display-referred image, after tone mapping.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PostInsertion>
A constant List of the values in this enum, in order of their declaration.