PropertyResolver class abstract

Computes a per-property animated value from a timeline of keyframes.

Subclasses cover the three AnimationProperty flavors with the correct interpolator: linear interpolation for translation and scale, spherical linear interpolation for rotation. Use the PropertyResolver factories to construct one rather than instantiating subclasses directly.

Implementers

Constructors

PropertyResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(AnimationTransforms target, double timeInSeconds, double weight) → void
Resolve and apply the property value to a target node. This operation is additive; a given node property may be amended by many different PropertyResolvers prior to rendering. For example, an AnimationPlayer may blend multiple Animations together by applying several AnimationClips.
getEndTime() double
Returns the end time of the property in seconds.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

makeRotationTimeline(List<double> times, List<Quaternion> values) PropertyResolver
Creates a rotation resolver that spherically interpolates between the keyframe quaternions in values at the corresponding times.
makeScaleTimeline(List<double> times, List<Vector3> values) PropertyResolver
Creates a scale resolver that linearly interpolates between the keyframe scales in values at the corresponding times.
makeTranslationTimeline(List<double> times, List<Vector3> values) PropertyResolver
Creates a translation resolver that linearly interpolates between the keyframe positions in values at the corresponding times.