makeRotationTimeline static method
Creates a rotation resolver that spherically interpolates between
the keyframe quaternions in values at the corresponding times.
times and values must have the same length and times must be
monotonically non-decreasing.
Implementation
static PropertyResolver makeRotationTimeline(
List<double> times,
List<Quaternion> values,
) {
return RotationTimelineResolver._(times, values);
}