makeScaleTimeline static method

PropertyResolver makeScaleTimeline(
  1. List<double> times,
  2. List<Vector3> values
)

Creates a scale resolver that linearly interpolates between the keyframe scales in values at the corresponding times.

times and values must have the same length and times must be monotonically non-decreasing.

Implementation

static PropertyResolver makeScaleTimeline(
  List<double> times,
  List<Vector3> values,
) {
  return ScaleTimelineResolver._(times, values);
}