makeTranslationTimeline static method

PropertyResolver makeTranslationTimeline(
  1. List<double> times,
  2. List<Vector3> values
)

Creates a translation resolver that linearly interpolates between the keyframe positions in values at the corresponding times.

times and values must have the same length and times must be monotonically non-decreasing.

Implementation

static PropertyResolver makeTranslationTimeline(
  List<double> times,
  List<Vector3> values,
) {
  return TranslationTimelineResolver._(times, values);
}