RectAreaLightComponent constructor
RectAreaLightComponent(
- RectAreaLight light
Creates a component that lights the scene with light.
Implementation
RectAreaLightComponent(this.light);
Creates a component that lights the scene with light.
RectAreaLightComponent(this.light);