blendDistance property
World-space fade band outside the box over which the probe's influence
falls from full to zero. 0 is a hard edge.
Implementation
double blendDistance;
World-space fade band outside the box over which the probe's influence
falls from full to zero. 0 is a hard edge.
double blendDistance;