captureOnActivate property
Whether the probe captures automatically before its first rendered frame. With this false, nothing renders from the probe until requestCapture.
Implementation
bool captureOnActivate;
Whether the probe captures automatically before its first rendered frame. With this false, nothing renders from the probe until requestCapture.
bool captureOnActivate;