pipelineBinds property
Pipeline binds that reached the backend (the encoder skips redundant binds, so this is the state-change count).
Implementation
int pipelineBinds = 0;
Pipeline binds that reached the backend (the encoder skips redundant binds, so this is the state-change count).
int pipelineBinds = 0;