dispose method
void
dispose()
Releases the progress notifier. Call when the group is no longer used; after disposal the group must not be added to or listened on.
Implementation
void dispose() => _progress.dispose();
Releases the progress notifier. Call when the group is no longer used; after disposal the group must not be added to or listened on.
void dispose() => _progress.dispose();