progress property

ValueListenable<double> get progress

Fraction of tracked loads that have settled, in the range 0 to 1.

A ValueListenable so a loading widget can rebuild as it changes without polling. It is 1 while the group is empty (nothing to wait for).

Implementation

ValueListenable<double> get progress => _progress;