collisionShape property

Shape get collisionShape

The matching physics collision shape. An annulus is not convex, so this is a CompoundShape of thin convex segments around the ring, which preserves the hole. See ringCollisionShape.

Implementation

Shape get collisionShape =>
    ringCollisionShape(innerRadius: _innerRadius, outerRadius: _outerRadius);