RotationModule class Particles
Integrates each particle's in-plane rotation from its angular velocity
(rotation += angularVelocity * dt).
- Inheritance
-
- Object
- ParticleModule
- RotationModule
Constructors
- RotationModule()
-
Creates a rotation integrator.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spawn(
ParticleStorage storage, int index) → void -
Initializes the freshly spawned particle at
index.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
ParticleStorage storage, double dt) → void -
Advances every live particle by
dtseconds.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited