RotationTimelineResolver class
Resolves a rotation timeline with spherical linear interpolation, slerping the current animated rotation toward the keyframed rotation by the supplied weight.
- Inheritance
-
- Object
- TimelineResolver
- RotationTimelineResolver
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
AnimationTransforms target, double timeInSeconds, double weight) → void -
Resolve and apply the property value to a target node. This
operation is additive; a given node property may be amended by
many different PropertyResolvers prior to rendering. For example,
an AnimationPlayer may blend multiple Animations together by
applying several AnimationClips.
override
-
getEndTime(
) → double -
Returns the end time of the property in seconds.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited