addRenderPass method

void addRenderPass(
  1. CustomRenderPass pass
)

Inserts pass into the render pipeline at its CustomRenderPass.stage. Passes at the same stage run in the order they were added. Adding the same pass twice is a no-op.

Implementation

void addRenderPass(CustomRenderPass pass) {
  if (_renderPasses.contains(pass)) return;
  _renderPasses.add(pass);
}