weight property
Blend weight in [0, 1]; overlapping clips are weight-blended and
normalized by the engine when the sum exceeds one.
Implementation
final double weight;
Blend weight in [0, 1]; overlapping clips are weight-blended and
normalized by the engine when the sum exceeds one.
final double weight;