SceneCameraBuilder typedef Widgets

SceneCameraBuilder = Camera Function(Duration elapsed)

Builds a Camera for the current frame from the elapsed time since the view started ticking. Use this for time-based cameras (for example an orbiting view); pass a fixed SceneView.camera instead when the camera does not change over time.

Implementation

typedef SceneCameraBuilder = Camera Function(Duration elapsed);