onLoaded property
Called with the imported model root after it mounts. Use it to reach imported content imperatively (play animations, look up nodes).
Implementation
final void Function(Node modelRoot)? onLoaded;
Called with the imported model root after it mounts. Use it to reach imported content imperatively (play animations, look up nodes).
final void Function(Node modelRoot)? onLoaded;