node property
Node?
get
node
The managed node, or null while the owning widget is unmounted.
Implementation
Node? get node => _state?._node;
The managed node, or null while the owning widget is unmounted.
Node? get node => _state?._node;