hit property
SceneRaycastHit?
get
hit
The latest raycast hit (from the occlusion set), or null when the ray misses everything in range.
Implementation
SceneRaycastHit? get hit => _hit;
The latest raycast hit (from the occlusion set), or null when the ray misses everything in range.
SceneRaycastHit? get hit => _hit;