autoTick property

bool autoTick
final

Whether to drive a repaint every frame with an internal Ticker.

Leave true (the default) for animated content. Set false for a static scene that only needs to repaint when the app rebuilds the view (for example with a new camera).

Implementation

final bool autoTick;