debugWidgetInput property

bool debugWidgetInput
final

Debug-only: overlays the automatic widget-input pointer's state (hit node, UV, distance, and a marker at the pointer position), the first tool to reach for when a widget surface does not respond to input.

Implementation

final bool debugWidgetInput;