scene property
The scene to render, owned and mutated by the application. Null when the view owns its scene (SceneView.declarative).
Implementation
final Scene? scene;
The scene to render, owned and mutated by the application. Null when the view owns its scene (SceneView.declarative).
final Scene? scene;