debugView property
A diagnostic visualization to render instead of the composited image. Defaults to SsrDebugView.composite (the normal output).
Implementation
SsrDebugView debugView = SsrDebugView.composite;
A diagnostic visualization to render instead of the composited image. Defaults to SsrDebugView.composite (the normal output).
SsrDebugView debugView = SsrDebugView.composite;