maxDistance property
How far, in world units, a reflected ray is marched before it is considered to have missed. Larger values let reflections reach more distant geometry at a higher trace cost.
Implementation
double maxDistance = 24.4;
How far, in world units, a reflected ray is marched before it is considered to have missed. Larger values let reflections reach more distant geometry at a higher trace cost.
double maxDistance = 24.4;