mean property

Vector3 mean
final

Mean reflected radiance over the sphere. For coefficients projected from an environment this equals the environment's average radiance, so a constant environment of radiance L round-trips to mean == L.

Implementation

final Vector3 mean;