ShaderCompileDiagnostic class final Debugging and profiling
One message from a shader compiler.
Constructors
- ShaderCompileDiagnostic({required String message, int? line, String? file, bool isError = true})
-
const
Properties
- file → String?
-
The file the compiler named, when it named one.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
final
- line → int?
-
The 1-based source line, when the compiler reported one.
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited