ShaderInstanceAttribute class Materials

A named custom value appended to an instanced mesh's instance record.

Constructors

ShaderInstanceAttribute(String name, ShaderInstanceAttributeType type)
Creates a raw shader instance attribute declaration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Shader input suffix. The vertex shader receives instance_<name>.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ShaderInstanceAttributeType
Number of components supplied for each instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited