ShapeCastHit class Physics
The first collider intersected by a shape cast, with the same fields as RaycastHit plus the cast direction's hit distance.
- Inheritance
-
- Object
- RaycastHit
- ShapeCastHit
Constructors
- ShapeCastHit({required Node node, required Component collider, required Vector3 worldPoint, required Vector3 worldNormal, required double distance})
Properties
- collider → Component
-
The specific collider that was hit, in case the node carries more
than one.
finalinherited
- distance → double
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- node → Node
-
The node whose collider was hit.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worldNormal → Vector3
-
finalinherited
- worldPoint → Vector3
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited