getTextureWidth method
The edge length, in texels, of the joints texture produced by getJointsTexture.
Implementation
int getTextureWidth() => _jointsTextureEdge(joints.length);
The edge length, in texels, of the joints texture produced by getJointsTexture.
int getTextureWidth() => _jointsTextureEdge(joints.length);