SkySource class abstract Lighting and environment

A source of skybox color as a function of world-space view direction.

A Skybox wraps a source and the engine draws it behind all scene geometry. Built-in sources are EnvironmentSkySource (show the scene's environment) and ShaderSkySource (a custom fragment shader).

Implementers

Constructors

SkySource()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited