collisionShape property
Shape
get
collisionShape
The matching physics collision shape, a sphere of the same radius.
Implementation
Shape get collisionShape => SphereShape(radius: _radius);
The matching physics collision shape, a sphere of the same radius.
Shape get collisionShape => SphereShape(radius: _radius);