SpotLightComponent constructor
SpotLightComponent(
- SpotLight light
Creates a component that lights the scene with light.
Implementation
SpotLightComponent(this.light);
Creates a component that lights the scene with light.
SpotLightComponent(this.light);