light property
The managed light. Mutated in place by resolve each frame so the scene graph need not re-register a new light when the sun moves.
Implementation
final DirectionalLight light = DirectionalLight();
The managed light. Mutated in place by resolve each frame so the scene graph need not re-register a new light when the sun moves.
final DirectionalLight light = DirectionalLight();