sunLightColor property
Vector3
get
sunLightColor
Linear-RGB color the sun contributes as a directional light. Combined with sunLightIntensity.
Implementation
Vector3 get sunLightColor;
Linear-RGB color the sun contributes as a directional light. Combined with sunLightIntensity.
Vector3 get sunLightColor;