objectMotion property

bool objectMotion
getter/setter pair

Whether moving objects render a velocity buffer. With this false only the camera's motion is reprojected, which is correct for a static scene and leaves trails behind moving geometry.

Implementation

bool objectMotion;