skinnedMotion property
Whether skinned meshes contribute deformation velocity, which needs the previous frame's joint matrices kept alive.
Implementation
bool skinnedMotion;
Whether skinned meshes contribute deformation velocity, which needs the previous frame's joint matrices kept alive.
bool skinnedMotion;