TextureContent enum Assets and loading

What a texture's pixels represent, which controls how mip levels are downsampled so the result is correct (color must average in linear light, normals must be averaged as vectors and renormalized).

Inheritance
Available extensions

Values

color → const TextureContent

sRGB-encoded color (albedo, emissive). Averaged in linear light.

data → const TextureContent

Linear data (metallic-roughness, ambient occlusion). Averaged directly.

normal → const TextureContent

A tangent-space normal map. Averaged as vectors and renormalized.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TextureContent>
A constant List of the values in this enum, in order of their declaration.