TriMeshShape class Physics

A triangle mesh defined by vertices (packed xyz triplets) and indices (groups of three vertex indices forming one triangle each).

Inheritance

Constructors

TriMeshShape({required Float32List vertices, required Uint32List indices})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
indices Uint32List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertices Float32List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited