TriggerEntered class Physics
Fired the first step a non-trigger collider overlaps a trigger volume.
- Inheritance
-
- Object
- CollisionEvent
- TriggerEntered
Constructors
- TriggerEntered({required Node nodeA, required Node nodeB, required Component colliderA, required Component colliderB})
Properties
- colliderA → Component
-
final
- colliderB → Component
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeA → Node
-
The node owning colliderA. nodeA and nodeB may be the same
when a compound body's children touch each other.
final
- nodeB → Node
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited