UniformColor class Particles

A ColorDistribution that picks a color between a and b per particle from its stored random (constant over the particle's life).

Inheritance

Constructors

UniformColor(Vector4 a, Vector4 b)
Creates a distribution that blends between a and b by the per-particle random.
const

Properties

a → Vector4
The two endpoint colors.
final
b → Vector4
The two endpoint colors.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sample(double normalizedAge, double random01, [Vector4? out]) → Vector4
Writes the color for a particle at normalizedAge with per-particle random random01 into out (allocated when null) and returns it.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited