UniformFloat class Particles
A FloatDistribution that picks a value in [min, max] per particle from
its stored random (constant over the particle's life).
- Inheritance
-
- Object
- FloatDistribution
- UniformFloat
Constructors
- UniformFloat(double min, double max)
-
Creates a uniform-range distribution over
[min, max].const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → double
-
Range bounds; min is returned at
random01 == 0, max near1.final - min → double
-
Range bounds; min is returned at
random01 == 0, max near1.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sample(
double normalizedAge, double random01) → double -
Returns the value for a particle at
normalizedAgewith per-particle randomrandom01.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited