alphaMode property
How the material's alpha is interpreted. AlphaMode.opaque ignores alpha; AlphaMode.blend routes the material through the depth-sorted translucent pass with alpha blending (use for widget textures and other surfaces with transparency).
Implementation
// TODO(materials): support AlphaMode.mask for unlit (needs a cutoff
// uniform and a discard in the unlit fragment shader); it currently
// behaves like blend.
AlphaMode alphaMode = AlphaMode.opaque;