offsetInBytes property
Byte offset of this attribute from the start of each element of the owning VertexBufferDescriptor.
Implementation
final int offsetInBytes;
Byte offset of this attribute from the start of each element of the owning VertexBufferDescriptor.
final int offsetInBytes;