onAttach method
Called when this component is added to a node.
Implementation
@override
void onAttach() {
controller.addListener(_onCapture);
}
Called when this component is added to a node.
@override
void onAttach() {
controller.addListener(_onCapture);
}