WidgetInput enum
How a WidgetComponent receives pointer input.
Values
- automatic → const WidgetInput
-
SceneViewforwards platform pointer events automatically: presses and drags raycast into the scene, and when this component's surface is the nearest hit, events forward at the hit UV. Occluded surfaces are blocked. - manual → const WidgetInput
-
No automatic forwarding; drive input through WidgetComponent.controller or a
ScenePointer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WidgetInput> - A constant List of the values in this enum, in order of their declaration.