kPrefilterBandWidth top-level constant
int
const kPrefilterBandWidth
Equirectangular width of a single roughness band in the atlas.
Implementation
const int kPrefilterBandWidth = 512;
Equirectangular width of a single roughness band in the atlas.
const int kPrefilterBandWidth = 512;