defaultValue property

PropertyValue? defaultValue
final

The value used when the property is absent from a spec, or null for a required property with no default (a mesh's geometry/material reference).

Implementation

final PropertyValue? defaultValue;