ConstantEnvironment class
A reflection-free environment with uniform diffuse ambient radiance.
- Inheritance
-
- Object
- EnvironmentSpec
- ConstantEnvironment
Constructors
- ConstantEnvironment(Vector3 color)
-
Creates a uniform diffuse environment with linear RGB
color.
Properties
- color → Vector3
-
Linear RGB radiance received by a white Lambertian surface.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited