EnvironmentSkySpec class

Shows the scene's image-based-lighting environment, optionally blurred.

Inheritance

Constructors

EnvironmentSkySpec({double blurriness = 0.0})
Creates the spec.

Properties

blurriness double
How blurred the background is, from 0.0 (sharp) to 1.0.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited