FmatSkySpec class

A sky .fmat loaded by source path, with optional parameter overrides applied to the loaded sky's parameters by name.

Inheritance

Constructors

FmatSkySpec(AssetRef asset, {Map<String, PropertyValue>? properties})
Creates the spec.

Properties

asset AssetRef
The .fmat source path (relative to the owning package's root).
final
hashCode int
The hash code for this object.
no setterinherited
properties Map<String, PropertyValue>
Parameter overrides, keyed by parameter name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited