realize method
Realizes spec into a live component, or returns null when no codec is
registered for its type.
Implementation
Component? realize(ComponentSpec spec, RealizeContext context) =>
_byType[spec.type]?.realize(spec, context);
Realizes spec into a live component, or returns null when no codec is
registered for its type.
Component? realize(ComponentSpec spec, RealizeContext context) =>
_byType[spec.type]?.realize(spec, context);