GizmoScalar class
A scalar parameter, a literal or a binding to a numeric property.
Constructors
- GizmoScalar(double value)
-
A literal scalar.
const
- GizmoScalar.bind(String bind, {double scale = 1})
-
Binds to the property at dotted path
bind, multiplied byscale.const
Properties
- bind → String?
-
The bound property path, or null for a literal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
Multiplier applied to a bound value.
final
- value → double?
-
The literal value, or null when bound.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Object? json) → GizmoScalar?