GradientSkySpec class
The built-in stylized gradient sky.
- Inheritance
-
- Object
- SkySourceSpec
- GradientSkySpec
Constructors
- GradientSkySpec({Vector3? zenithColor, Vector3? horizonColor, Vector3? groundColor, Vector3? sunDirection, Vector3? sunColor, double sunSharpness = 400.0})
- Creates the spec with the runtime defaults.
Properties
- groundColor ↔ Vector3
-
The color below the horizon.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizonColor ↔ Vector3
-
The sky color at the horizon.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sunColor ↔ Vector3
-
The sun disk color, linear HDR.
getter/setter pair
- sunDirection ↔ Vector3
-
Direction toward the sun.
getter/setter pair
- sunSharpness ↔ double
-
Sharpness exponent of the sun disk.
getter/setter pair
- zenithColor ↔ Vector3
-
The sky color straight up.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited