PayloadEncoding enum
How a binary payload chunk's bytes are interpreted.
Values
- vertexBuffer → const PayloadEncoding
-
An interleaved vertex buffer (see PayloadSpec.layout).
- indexBuffer → const PayloadEncoding
-
An index buffer.
- image → const PayloadEncoding
-
An encoded or raw image (see PayloadSpec.format).
- matrices → const PayloadEncoding
-
A packed array of 4x4 matrices.
- floats → const PayloadEncoding
-
A packed array of 32-bit floats.
- bytes → const PayloadEncoding
-
Opaque bytes.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PayloadEncoding> - A constant List of the values in this enum, in order of their declaration.