PlaneGeometrySpec class
A flat plane in the XZ plane.
- Inheritance
-
- Object
- ProceduralGeometry
- PlaneGeometrySpec
Constructors
- PlaneGeometrySpec({double width = 1.0, double depth = 1.0, int segmentsX = 1, int segmentsZ = 1})
- Creates a plane spec.
Properties
- depth → double
-
Size along Z.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentsX → int
-
Grid subdivisions along X.
final
- segmentsZ → int
-
Grid subdivisions along Z.
final
- width → double
-
Size along X.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited