PropertyOverride class

One per-instance override of a prefab: set the property at path on the node target (in the prefab's local id space) to value.

Constructors

PropertyOverride({required LocalId target, required String path, required PropertyValue value})
Creates an override of path on target to value.

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
A dotted property path, for example components.mesh.material or transform.trs.t.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target LocalId
The node in the referenced prefab whose property is overridden.
final
value PropertyValue
The overriding value (absolute, not a relative delta).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited