RenderTextureResource class
An offscreen render target a serialized render view draws into and
materials sample by id (the runtime RenderTexture).
- Inheritance
-
- Object
- ResourceSpec
- RenderTextureResource
Constructors
Properties
- filter → String
-
The sampling filter name (
linear,nearest).final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Target height in physical pixels.
final
- id → LocalId
-
This resource's stable, document-scoped id.
finalinherited
- intervalMilliseconds → int?
-
The interval for the
intervalpolicy, in milliseconds.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- update → String
-
The update policy name (
everyFrame,interval,manual), mapped to the runtimeRenderTextureUpdateat realization.final - width → int
-
Target width in physical pixels.
final
- wrap → String
-
The sampling wrap-mode name (
clampToEdge,repeat,mirror).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited