SkySourceSpec class sealed
What a stage sky looks like, serialized.
Realized to a runtime SkySource by the stage realizer: the environment
sky and the built-in gradient/physical skies realize from their fields;
an fmat sky loads its .fmat by source path.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited