SortedDescending class final
A list of objects must stay sorted by strictly descending fieldName (LOD levels by screen size).
- Inheritance
-
- Object
- PropertyConstraint<
List< Object?> > - SortedDescending
Constructors
- SortedDescending(String fieldName)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
The tagged JSON form, a single-key map (
{'range': {...}}).override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited