loadFscenebBytesAsync function
Future<Node>
loadFscenebBytesAsync(
- Uint8List bytes, {
- FsceneComponentRegistry? registry,
- AssetBundle? bundle,
Parses a .fsceneb container from bytes and realizes it, first loading
any external assets, encoded image payloads, and fmat materials it
references (from bundle, default rootBundle).
Implementation
Future<Node> loadFscenebBytesAsync(
Uint8List bytes, {
FsceneComponentRegistry? registry,
AssetBundle? bundle,
}) => realizeSceneAsync(readFsceneb(bytes), registry: registry, bundle: bundle);