VertexFormat enum
Values
- float32 → const VertexFormat
-
const VertexFormat(bytesPerElement: 4, componentCount: 1) - float32x2 → const VertexFormat
-
const VertexFormat(bytesPerElement: 8, componentCount: 2) - float32x3 → const VertexFormat
-
const VertexFormat(bytesPerElement: 12, componentCount: 3) - float32x4 → const VertexFormat
-
const VertexFormat(bytesPerElement: 16, componentCount: 4) - uint32 → const VertexFormat
-
const VertexFormat(bytesPerElement: 4, componentCount: 1) - uint32x2 → const VertexFormat
-
const VertexFormat(bytesPerElement: 8, componentCount: 2) - uint32x3 → const VertexFormat
-
const VertexFormat(bytesPerElement: 12, componentCount: 3) - uint32x4 → const VertexFormat
-
const VertexFormat(bytesPerElement: 16, componentCount: 4) - sint32 → const VertexFormat
-
const VertexFormat(bytesPerElement: 4, componentCount: 1) - sint32x2 → const VertexFormat
-
const VertexFormat(bytesPerElement: 8, componentCount: 2) - sint32x3 → const VertexFormat
-
const VertexFormat(bytesPerElement: 12, componentCount: 3) - sint32x4 → const VertexFormat
-
const VertexFormat(bytesPerElement: 16, componentCount: 4)
Properties
- bytesPerElement → int
-
final
- componentCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VertexFormat> - A constant List of the values in this enum, in order of their declaration.