AtmosphericLighting class Gameplay kit
Evaluated atmospheric lighting parameters for a specific sun elevation.
Constructors
- AtmosphericLighting({required Vector3 sunColor, required double sunIntensity, required double environmentIntensity, required double shadowDarkness})
- Creates an atmospheric lighting record.
Properties
- environmentIntensity → double
-
Ambient environment intensity multiplier for
Scene.environmentIntensity.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowDarkness → double
-
Shadow darkness factor (0.0 = completely dark, 1.0 = standard shadows).
final
- sunColor → Vector3
-
Directional sun light color in linear RGB.
final
- sunIntensity → double
-
Directional sun light illuminance in lux.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited