BoundsFraming class Gameplay kit
Utility for computing camera framing transforms for scene nodes.
Computes a look-at transform placing a camera node so that a target bounding box fills the view. For standalone camera instances, prefer PerspectiveCamera.framing.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
computeFramingTransform(
Aabb3 bounds, CameraProjection projection, {double paddingFactor = 1.25, Vector3? viewDirection, Vector3? upVector}) → Matrix4 -
Computes a camera node world transform that frames
boundswithpaddingFactor.