GerstnerWave class Gameplay kit
Definition of a single directional Gerstner wave.
Constructors
- GerstnerWave({required Vector2 direction, double amplitude = 0.5, double wavelength = 10.0, double speed = 1.5, double steepness = 0.8})
Properties
- amplitude → double
-
Crest height amplitude in world units.
final
- direction → Vector2
-
Normalized 2D wave propagation direction vector.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
Propagation speed multiplier.
final
- steepness → double
-
Trochoidal crest sharpness factor between 0.0 (sine) and 1.0 (sharp crests).
final
- wavelength → double
-
Distance between wave crests in world units.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited