SoundManager class Audio
High-level audio utility providing one-shot sound playback with pitch jitter and 3D positioning.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
playOneShot(
AudioEngine engine, AudioClip clip, {Vector3? position, double volume = 1.0, double pitchJitter = 0.05, AudioAttenuation? attenuation, AudioBus? bus}) → AudioVoice - Plays an audio clip once with optional pitch jitter, attenuation curve, and 3D positioning.