SurfaceFootstepAudio class Audio
Helper mapping surface material tags to audio clip banks.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playFootstep(
AudioEngine engine, SurfaceMaterialType type, {Vector3? position, double volume = 0.8}) → void -
Plays a random footstep sound for
typeat world positionposition. -
registerClips(
SurfaceMaterialType type, List< AudioClip> clips) → void - Registers a list of audio clips for a specific surface type.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited