CollisionBegan class Physics
Two solid colliders began touching.
- Inheritance
-
- Object
- CollisionEvent
- CollisionBegan
Constructors
-
CollisionBegan({required Node nodeA, required Node nodeB, required Component colliderA, required Component colliderB, List<
ContactPoint> contacts = const []})
Properties
- colliderA → Component
-
finalinherited
- colliderB → Component
-
finalinherited
-
contacts
→ List<
ContactPoint> -
The contact manifold at the moment contact began. May be empty when
the backend does not report contact details.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeA → Node
-
finalinherited
- nodeB → Node
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited