JointAxisConfig class
Motion allowance for one axis of a generic joint.
Constructors
- JointAxisConfig.free({JointMotor? motor})
-
const
- JointAxisConfig.limited(double lower, double upper, {JointMotor? motor})
-
const
- JointAxisConfig.locked()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowerLimit → double
-
final
- motion → JointAxisMotion
-
final
- motor → JointMotor?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upperLimit → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited