AntiAliasingMode enum

Anti-aliasing strategy used when rendering a Scene.

Set on a Scene via Scene.antiAliasingMode. The default is msaa when the GPU backend supports offscreen MSAA, otherwise none.

Inheritance
Available extensions

Values

none → const AntiAliasingMode

No anti-aliasing. Geometry edges are rendered at the render target's native resolution.

msaa → const AntiAliasingMode

4x multi-sample anti-aliasing. Requires offscreen MSAA support on the active Flutter GPU backend; setting this mode is silently ignored (with a debug warning) when MSAA is unavailable.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AntiAliasingMode>
A constant List of the values in this enum, in order of their declaration.