BoxVolumeBounds class Lighting and environment
An axis-aligned box region.
- Inheritance
-
- Object
- EnvironmentVolumeBounds
- BoxVolumeBounds
Constructors
- BoxVolumeBounds({required Vector3 center, required Vector3 halfExtents})
Properties
- center ↔ Vector3
-
World-space center.
getter/setter pair
- halfExtents ↔ Vector3
-
Half the box size along each axis.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
distanceTo(
Vector3 point) → double -
Distance from
pointto the boundary surface in world units,0whenpointis inside.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited