onDetach method
Called when this component is removed from a node.
Implementation
@override
void onDetach() {
// A reattachment may bind a different node, so drop the cached camera.
_camera = null;
}
Called when this component is removed from a node.
@override
void onDetach() {
// A reattachment may bind a different node, so drop the cached camera.
_camera = null;
}