getProjectionMatrix abstract method
Returns the projection matrix for a render target of the given
aspectRatio (width / height).
Implementation
Matrix4 getProjectionMatrix(double aspectRatio);
Returns the projection matrix for a render target of the given
aspectRatio (width / height).
Matrix4 getProjectionMatrix(double aspectRatio);