update method

void update(
  1. double deltaSeconds
)

Called once per frame while the component is mounted, enabled, and loaded. deltaSeconds is the elapsed time since the previous tick.

Implementation

void update(double deltaSeconds) {}