ConstantColor class Particles
A ColorDistribution that is color for every particle.
- Inheritance
-
- Object
- ColorDistribution
- ConstantColor
Constructors
- ConstantColor(Vector4 color)
-
Creates a constant color distribution.
const
Properties
- color → Vector4
-
The constant linear RGBA color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sample(
double normalizedAge, double random01, [Vector4? out]) → Vector4 -
Writes the color for a particle at
normalizedAgewith per-particle randomrandom01intoout(allocated when null) and returns it.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited