mipRadianceLayoutSupported property
bool
get
mipRadianceLayoutSupported
Whether the active Flutter GPU backend can build and sample the mip radiance layout: rendering into non-zero mip levels plus sampling hand-written mip chains.
Currently false on the native GLES backend (Impeller does not yet implement render-to-mip-level there), where new environments build the legacy band atlas regardless of useMipRadianceLayout.
Implementation
static bool get mipRadianceLayoutSupported =>
gpu.gpuContext.doesSupportFramebufferRenderMipmap &&
gpu.gpuContext.doesSupportManuallyMippedTextures;