bind abstract method
void
bind(
- RenderPass pass,
- HostBuffer transientsBuffer,
- Matrix4 modelTransform,
- Matrix4 cameraTransform,
- Vector3 cameraPosition,
Binds vertex/index buffers and per-frame uniforms onto pass in
preparation for a draw call.
Implementations write the model and camera transforms (and any subclass-specific values, like the joints texture for skinned geometry) into the supplied transient buffer and bind the resulting uniform views.
Implementation
void bind(
gpu.RenderPass pass,
gpu.HostBuffer transientsBuffer,
vm.Matrix4 modelTransform,
vm.Matrix4 cameraTransform,
vm.Vector3 cameraPosition,
);