setJointsTexture method
Hook for skinned geometries to receive the joints texture computed by Skin.getJointsTexture.
The default implementation does nothing; SkinnedGeometry overrides it to bind the texture in bind.
Implementation
void setJointsTexture(gpu.Texture? texture, int width) {}