IrradianceFieldBake class Lighting and environment
A baked irradiance field, serializable into an .fscene document and
assignable to IrradianceVolumeComponent.bake.
Constructors
- IrradianceFieldBake({required Vector3 origin, required Vector3 spacing, required Vector3 resolution, required Uint8List atlasBytes})
Properties
- atlasBytes → Uint8List
-
Raw half-float bytes of the complete atlas.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- origin → Vector3
-
World-space origin of the minimum corner probe.
final
- resolution → Vector3
-
Probe count along each axis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → Vector3
-
Distance between adjacent probes along each axis.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited