normals property
Optional per-endpoint surface normals matching positions, carried from the source mesh so callers can offset segments off the surface.
Implementation
final Float32List? normals;
Optional per-endpoint surface normals matching positions, carried from the source mesh so callers can offset segments off the surface.
final Float32List? normals;