isOpaque method
Whether geometry rendered with this material is fully opaque.
The renderer uses this to split draws into the opaque and translucent passes (see SceneEncoder). Translucent draws are depth-sorted and drawn after the opaque pass with alpha blending enabled.
Implementation
bool isOpaque() {
return true;
}