Mesh class base
Defines the shape and appearance of a 3D model in the scene.
It consists of a list of MeshPrimitive instances, where each primitive contains the Geometry and the Material to render a specific part of the 3d model.
Constructors
- Mesh(Geometry geometry, Material material)
-
Creates a
Meshconsisting of a single MeshPrimitive with the given Geometry and Material. -
Mesh.primitives({required List<
MeshPrimitive> primitives}) -
Creates a
Meshcomposed of the supplied MeshPrimitive list.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- localBounds → Aabb3?
-
Local-space union of every primitive's Geometry.localBounds, or
nullwhen no primitive has computable bounds.no setter -
primitives
→ List<
MeshPrimitive> -
The list of MeshPrimitive objects that make up the Geometry and Material of the 3D model.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
markLocalBoundsDirty(
) → void - Invalidate the cached localBounds. Call this after replacing a primitive's geometry.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited