MeshParticleFacing enum Particles
How a mesh particle orients itself.
Values
- tumble → const MeshParticleFacing
-
Tumbles around the particle's random unit axis by its rotation (which
RotationModuleintegrates from the angular velocity). The default, suited to debris and shrapnel. - velocityAligned → const MeshParticleFacing
-
The mesh's
+Yaxis follows the particle's velocity, spinning around it by the particle's rotation. Suited to darts, shards, and anything that should fly point-first.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MeshParticleFacing> - A constant List of the values in this enum, in order of their declaration.