setMorphWeight method
Sets the weight of morph target index on this node instance.
Throws a StateError when the mesh has no morph targets and a
RangeError when index is outside [0, morphTargetCount).
Implementation
void setMorphWeight(int index, double value) {
final live = internalMorphWeights;
if (live == null) {
throw StateError("This node's mesh has no morph targets");
}
live[index] = value;
}