highlightStyle property
How the selection outline is drawn around nodes that have a Node.highlightColor. No outline is drawn when no node is highlighted.
Implementation
final HighlightStyle highlightStyle = HighlightStyle();
How the selection outline is drawn around nodes that have a Node.highlightColor. No outline is drawn when no node is highlighted.
final HighlightStyle highlightStyle = HighlightStyle();