loadingBuilder property
Builds the widget shown while the view waits to reveal the scene.
Called with the current load progress (the loading group's progress,
or 0 until static resources are ready when there is no group). When null,
the space is left blank until the scene is revealed.
Implementation
final SceneLoadingBuilder? loadingBuilder;