fadeStart property
double
get
fadeStart
Radial distance from the mesh origin, in the mesh's local units, where the overlay starts fading out. See fadeEnd.
Implementation
double get fadeStart => _fadeStart;
set
fadeStart
(double value)
Implementation
set fadeStart(double value) {
_fadeStart = value;
_paramsDirty = true;
}