getTextureWidth method
The edge length, in texels, of the joints texture produced by getJointsTexture.
Implementation
int getTextureWidth() {
return _getNextPowerOfTwoSize(sqrt(joints.length * 4).ceil());
}
The edge length, in texels, of the joints texture produced by getJointsTexture.
int getTextureWidth() {
return _getNextPowerOfTwoSize(sqrt(joints.length * 4).ceil());
}