setJointsTexture method

  1. @override
void setJointsTexture(
  1. Texture? texture,
  2. int width
)
override

Hook for skinned geometries to receive the joints texture computed by Skin.getJointsTexture.

The default implementation does nothing; SkinnedGeometry overrides it to bind the texture in bind.

Implementation

@override
void setJointsTexture(gpu.Texture? texture, int width) {
  _jointsTexture = texture;
  _jointsTextureWidth = width;
}