emplace abstract method
Appends bytes and returns a view referencing them, aligned per the
writer's purpose. The view must only be used by work submitted this
frame.
Implementation
gpu.BufferView emplace(ByteData bytes);
Appends bytes and returns a view referencing them, aligned per the
writer's purpose. The view must only be used by work submitted this
frame.
gpu.BufferView emplace(ByteData bytes);