UniformColor class Particles
A ColorDistribution that picks a color between a and b per particle from its stored random (constant over the particle's life).
- Inheritance
-
- Object
- ColorDistribution
- UniformColor
Constructors
- UniformColor(Vector4 a, Vector4 b)
-
Creates a distribution that blends between
aandbby the per-particle random.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sample(
double normalizedAge, double random01, [Vector4? out]) → Vector4 -
Writes the color for a particle at
normalizedAgewith per-particle randomrandom01intoout(allocated when null) and returns it.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited